<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Base controller for all controllers in application
 */
class BaseController extends CController
{
    private $_assetsPath;
    private $_clientParams;

    public $layout = '//layouts/gportal';
    public $mailLayout = '//layouts/mail';

    protected function beforeAction($action) {
        $this->layout = Yii::app()->getModule('settings')->layoutForBackend;
        return parent::beforeAction($action);
    }
    /**
     * Temporary dummy method
     *
     * @return object with configuration info
     */
    public function getClient()
    {
        // parse domain
        // get configuration for this domain
        // return configuration object for domain
        $this->_clientParams = new stdClass;
        $this->_clientParams->username = Yii::app()->params['client']['username'];
        $this->_clientParams->contentPath = Yii::app()->params['storageFolder'] . DIRECTORY_SEPARATOR . $this->_clientParams->username;
        return $this->_clientParams;
    }

    /**
     * CAssetManager is a Web application component that manages private files
     * (called assets) and makes them accessible by Web clients.
     * It achieves this goal by copying assets to a Web-accessible directory
     * and returns the corresponding URL for accessing them.
     *
     * @throws CException
     * @return string the root directory storing the published asset files. Defaults to 'WebRoot/assets'.
     */
    public function getAssetsPath()
    {
        if (is_null($this->_assetsPath)) {
            $assetsPath = ($this->module !== null) ? $this->module->name . '/assets' : Yii::app()->controller->client->contentPath;
            if (($assetsPath = realpath($assetsPath)) === false || !is_dir($assetsPath) || !is_writable($assetsPath)) {
                throw new CException(
                    Yii::t('yii', 'CAssetManager.basePath "{path}" is invalid. Please make sure the directory exists and is writable by the Web server process.', array('{path}' => $assetsPath))
                );
            }
            $this->_assetsPath = Yii::app()->assetManager->publish($assetsPath, false, -1, false);
        }
        return $this->_assetsPath;
    }
    /**
     * Finds a view file based on its name.
     * The view with such name will be looked for in the custom and common sections (priority for custom).
     * View seeking in the custom area enables with parameter  'customViews' = true in the 'params' of the config/main
     * @param string $viewName the view name
     * @param string $viewPath the directory that is used to search for a relative view name
     * @param string $basePath the directory that is used to search for an absolute view name under the application
     * @param string $moduleViewPath the directory that is used to search for an absolute view name under the current module.
     * If this is not set, the application base view path will be used.
     * @return mixed the view file path. False if the view file does not exist.
     */
    public function resolveViewFile($viewName, $viewPath, $basePath, $moduleViewPath = null)
    {
        if (empty($viewName)) {
            return false;
        }
        if ($moduleViewPath === null) {
            $moduleViewPath = $basePath;
        }
        if (($renderer = Yii::app()->getViewRenderer()) !== null) {
            $extension = $renderer->fileExtension;
        } else {
            $extension='.php';
        }
        if ($viewName[0]==='/') {
            if (strncmp($viewName,'//',2) === 0) {
                $commonViewFile = $basePath.$viewName;
            } else {
                $commonViewFile = $moduleViewPath.$viewName;
            }
        } elseif (strpos($viewName,'.')) {
            $commonViewFile = Yii::getPathOfAlias($viewName);
        } else{
            $commonViewFile = $viewPath.DIRECTORY_SEPARATOR . $viewName;
        }
        $sections = array($commonViewFile);
        if (isset(Yii::app()->params['customViews']) && Yii::app()->params['customViews'] == true) {
            $from = array('common' . DIRECTORY_SEPARATOR . 'modules', 'frontend' . DIRECTORY_SEPARATOR . 'views');
            $to = array('custom' . DIRECTORY_SEPARATOR . 'modules', 'custom' . DIRECTORY_SEPARATOR . 'views');
            $customViewFile = str_replace($from, $to, $commonViewFile);
            array_unshift($sections, $customViewFile);
        }
        foreach ($sections as $viewFile) {
            if (is_file($viewFile . $extension)) {
                return Yii::app()->findLocalizedFile($viewFile . $extension);
            } elseif($extension !== '.php' && is_file($viewFile . '.php')) {
                return Yii::app()->findLocalizedFile($viewFile . '.php');
            }
        }
        return false;
    }

    function getJs($path){
        echo "<script src=" . $path . "></script>";
    }

    public function renderMail($view, $title = null, $data, $return = true)
    {
        $pathToView = Yii::getPathOfAlias($view);
        $module = null;
        preg_match("/\\\\modules\\\\(?P<module_id>\w+)\\\\/", $pathToView, $matches);
        if (!empty($matches)) {
            $module = $matches['module_id'];
            $module = Yii::app()->getModule($module);
            $this->mailLayout = isset($module->mainMailTemplate) ? $module->mainMailTemplate : $this->mailLayout;
        }
        $output = $this->renderPartial($view, $data, true);
        if (($layoutFile = $this->getLayoutFile($this->mailLayout)) !== false) {
            $output = $this->renderFile($layoutFile, array('content' => $output, 'title' => $title), true);
        }
        if ($return) {
            return $output;
        } else {
            echo $output;
        }
    }

    public function redirect($url,$terminate=true,$statusCode=302)
    {
        //escaping from CRLF injection
        $exceptModules = array('user');
        $moduleId = isset(Yii::app()->controller->module->id)?Yii::app()->controller->module->id:false;
        if(!$moduleId || ($moduleId && !in_array($moduleId, $exceptModules))){
            new AppHelper(); //this file contains function http_build_url
            $url = http_build_url('', parse_url($url));
        }
        parent::redirect($url, $terminate, $statusCode);
    }
    /**
     * Overridden parent method. Add possibility to load widget classes from /custom folder
     *
     * @param string $className class name (can be in path alias format)
     * @param array $properties initial property values
     * @return CWidget the fully initialized widget instance.
     */
    public function createWidget($className,$properties=array())
    {
        if (isset(Yii::app()->params['customWidgets']) && Yii::app()->params['customWidgets'] == true) {

            $pattern = '/^(.*?modules\.)?(.*)$/';
            $replacement = 'custom.modules.${2}';
            $custClassName = preg_replace($pattern, $replacement, $className);

            if (file_exists(Yii::getPathOfAlias($custClassName).'.php')) {
                $className = $custClassName;
            }
        }
        return parent::createWidget($className,$properties);
    }

    /**
     * Determines the mimetype, using the YII method
     * CFileHelper::getMimeTypeByExtension and sets the HTTP response header
     * accordingly
     * @param string $fileName The filename
     */
    public function setContentTypeByFileName($fileName)
    {
        // We don't use CFileHelper::getMimeType here, because PHPs finfo
        // function doesn't handle Files like docx properly.
        $mimeType = CFileHelper::getMimeTypeByExtension($fileName);
        if ($mimeType !== null) {
            header("Content-Type: " . $mimeType);
        }
    }

    /**
     * Sends a binary file to the requesting client with the correct
     * Content-Type for this file and exits.
     * All other HTTP headers like caching must be sent before calling this.
     * @param type $filePath  Path to the file
     */
    public function renderBinaryFile($filePath)
    {
        $this->setContentTypeByFileName($filePath);
        die(file_get_contents($filePath));
    }
}
