<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 */
class m120321_154445_right extends CDbMigration
{
    public function safeUp()
    {
        $this->createTable('AuthItem', array(
            'name' => 'string',
            'type' => 'integer not null',
            'description' => 'text',
            'bizrule' => 'text',
            'data' => 'text',
        ));
        $this->createIndex('name', 'AuthItem', 'name', true);

        $this->createTable('AuthItemChild', array(
            'parent' => 'string not null',
            'child' => 'string not null',
        ));
        $this->createIndex('AuthItemChild_parent_idx', 'AuthItemChild', 'parent');
        $this->createIndex('AuthItemChild_child_idx', 'AuthItemChild', 'child');

        $this->addForeignKey('parent_name_ref', 'AuthItemChild', 'parent', 'AuthItem', 'name', 'cascade', 'cascade');
        $this->addForeignKey('child_name_ref', 'AuthItemChild', 'child', 'AuthItem', 'name', 'cascade', 'cascade');

        $this->createTable('AuthAssignment', array(
            'itemname' => 'string not null',
            'userid' => 'integer not null',
            'bizrule' => 'text',
            'data' => 'text',
        ));
        $this->createIndex('AuthAssignment_itemname_userid_idx', 'AuthAssignment', 'itemname, userid');

        $this->addForeignKey('assign_itemname_name_ref', 'AuthAssignment', 'itemname', 'AuthItem', 'name', 'cascade', 'cascade');

        $this->createTable('Rights', array(
            'itemname' => 'string not null',
            'type' => 'integer not null',
            'weight' => 'integer not null',
        ));
        $this->createIndex('Rights_itemname_idx', 'Rights', 'itemname');

        $this->addForeignKey('right_itemname_name_ref', 'Rights', 'itemname', 'AuthItem', 'name', 'cascade', 'cascade');

        $this->insert('AuthItem', array(
            'name' => 'Admin',
            'type' => '2',
            'description' => 'Administrator',
            'bizrule' => null,
            'data' => 'N;'
        ));

        $res = Yii::app()->db->createCommand()->select('id')->from('{{users}}')
            ->where('username=:username', array(':username' => 'admin'))
            ->queryRow();
        $this->insert('AuthAssignment', array(
            'itemname' => 'Admin',
            'userid' => $res['id'],
            'bizrule' => null,
            'data' => 'N;'
        ));
    }

    public function safeDown()
    {
        $this->dropTable('Rights');
        $this->dropTable('AuthItemChild');
        $this->dropTable('AuthAssignment');
        $this->dropTable('AuthItem');
    }

}