<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Interface, which has to be implemented by all classes that resolve MarkA PageIDs to 
 * page infos (e.g. name and URL of the page).
 * The iMarkaPageInfosProviders, which should be used by the SuggestionsController can be
 * configured in the config.
 */
 interface iMarkaPageInfosProvider
{

    /**
     * Retrieves the requested attributes for the specified Marketing Automation page IDs,
     * which have the prefix that this iMarkaPageInfosProvider handles,
     * and returns an associative array with all page infos found in the repository. Each 
     * Marketing Automation page ID from the markaPageIds array will be associated with one
     * page infos associative array. Each of these page infos arrays contains the requested page attributes
     * (e.g. array('name' => 'Soccer', 'url' => '/sports/Soccer.html') for the
     * corresponding page. If any of the attributes was not found for a page or was empty, the
     * entry in the array will exist, but will be NULL. If no attributes were found for a
     * particular page, there will be no entry for that page ID in the returned array.
     *
     * Note that this function does not interact with the cache in any way. The SuggestionsController
     * will first check if the page infos for a page ID are available in the cache and only if they are not,
     * add it to the array, which is passed to this function. The insertion of page infos into the cache
     * is also handled by the SuggestionsController.
     * 
     * @param array $markaPageIds the array of page IDs with this iMarkaPageInfosProvider's
     * prefix, as returned by Marketing Automation
     * @param array $pageAttributes the page attributes (CMS or repository attributes,
     * not Marketing Automation attributes) that should be retrieved for each page
     * @return array
     */
    public function getPageInfos($markaPageIds, $pageAttributes);

}