<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Item controller class file.
 */
class ItemController extends SCBaseController
{
    /*
     * Add item to cart
     * Function adds the item to order cart or update necessary values in exist record
     * @return void
     */
    public function actionAdd()
    {
        $model = new Item;

        $this->csrfProtect();

        if(isset($_POST['Item']) && is_numeric($_POST['Item']['quantity']) && $_POST['Item']['quantity'] > 0)
        {
            $order_id = Order::getOrder(true);
            $item_id  = EncryptHelper::decrypt($_POST['Item']['item_id']);

            $exist_model = Item::model()->find('item_id=:item_id AND order_id=:order_id',
                array(':item_id' =>$item_id,
                      ':order_id'=>$order_id
                )
            );

            if(isset($exist_model)){
                $model = $exist_model;
                $model->quantity += $_POST['Item']['quantity'];
                $model->ordered_at = new CDbExpression('NOW()');
            }else{
                $model->title       =EncryptHelper::decrypt($_POST['Item']['title']);
                $model->quantity    =$_POST['Item']['quantity'];
                $model->price       =EncryptHelper::decrypt($_POST['Item']['price']);
                $model->item_id     =$item_id;
                $model->page_id     =EncryptHelper::decrypt($_POST['Item']['page_id']);
                $model->admin_email =EncryptHelper::decrypt($_POST['Item']['admin_email']);
                $model->order_id    =$order_id;
                $model->item_referrer    =$_POST['Item']['item_referrer'];
            }
            $model->ip_address  =$_SERVER['REMOTE_ADDR'];
            $model->referrer    =$_SERVER['HTTP_REFERER'];

            if($model->getItemChecksum()==$_POST['checksum']){
                if($model->save()){
                    Order::flushOrder();
                    //Extend the lifespan of cookie
                    if (!headers_sent()){
                        $cookie = new CHttpCookie('user_id', Order::getUser(true));
                        $cookie->expire = time()+60 * Yii::app()->getModule('shoppingcart')->max_lifetime;
                        if(isset(Yii::app()->getModule('shoppingcart')->cookie_domain)){
                            $cookie->domain = Yii::app()->getModule('shoppingcart')->cookie_domain;
                        }
                        Yii::app()->request->cookies['user_id'] = $cookie;
                    }
                    Yii::app()->user->setFlash('itemAdded',ShoppingcartModule::t('Item successfully added'));
                }
            }
        }

        if (!empty($_POST['shoppingcart_link'])) {
           $this->redirect($_POST['shoppingcart_link']);
        } elseif(isset($_SERVER['HTTP_REFERER'])) {
           Yii::app()->user->setState('criticalReferrer',$_SERVER['HTTP_REFERER']);
           $this->redirect($_SERVER['HTTP_REFERER'].'#item-'.$model->item_id);
        }
    }
    /*
     * Delete item from cart by id
     * @throws CHttpException
     * @return void
     */
    public function actionRemove()
    {
        $this->csrfProtect();

        if (isset($_GET['id'])) {
            // we only allow deletion via POST request
            $model = Item::model()->findByPk($_GET['id']);
            if (isset($model) && (Order::getOrder(true)==$model->order_id)) {
                $model->delete();
                Order::flushOrder();
            } else {
                throw new CHttpException(403);
            }
            if(isset($_SERVER['HTTP_REFERER'])){
                $this->redirect($_SERVER['HTTP_REFERER']);
            }
        }
    }
}