/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */

(function ($) {
    $.fn.dhtmlTreeEditor = function (options) {
        var defaults = {
            saveUrl:null,
            deleteUrl:null,
            treeData:null,
            treeClass:'dhtmlTree',
            controlsClass:'dhtmlTreeControls',
            imagePath:null,
            t:{},
            hiddenFields:{}
        };
        options = $.extend(defaults, options);
        var t = function (msg) {
            if (options.t[msg]) {
                return options.t[msg];
            } else {
                return msg;
            }
        };

        this.each(function () {
            var $this = $(this);


            $this.append("<div><div class='" + options.treeClass + "'></div><div class='" + options.controlsClass + "'></div></div>");
            $this.find('.' + options.controlsClass).append(
                '<div class="controls">' +
                    '<div><button name="new">' + t('New') + '</button><button name="delete">' + t('Delete') + '</button></div>' +
                    '<div>' +
                    '<label>' + t('Name') + '</label><input type="text" name="name"> <br/><label>' + t('Title') + '</label><input type="text" name="title"><br/>' +
                    '<button name="save">' + t('Save') + '</button>' +
                    '<div class="status"></div>' +
                    '</div>' +
                    '</div>'
            );
            var $new = $this.find('[name="new"]');
            var $delete = $this.find('[name="delete"]');
            var $save = $this.find('[name="save"]');
            var $name = $this.find('[name="name"]');
            var $title = $this.find('[name="title"]');

            $name.keypress(function () {
                $save.removeAttr('disabled');
            });
            $title.keypress(function () {
                $save.removeAttr('disabled');
            });

            var tree = new dhtmlXTreeObject($this.find('.' + options.treeClass)[0], "100%", "100%", 0);
            tree.setSkin('dhx_skyblue');
            tree.enableTreeImages(false);
            tree.enableTreeLines(true);
            tree.setImagePath(options.imagePath);
            tree.loadJSONObject({
                id:0,
                item:[
                    {
                        id:'root',
                        text:t('Personalisation attributes tree'),
                        item:options.treeData
                    }
                ]});
            tree.openAllItems(0);
            tree.setOnClickHandler(function (id) {
                editItem(id);
            });

            $new.click(function () {
                var defaultName = t('new_attribute');
                var id = 'tmp_' + (new Date()).getTime();
                var parentId = tree.getSelectedItemId();
                if (parentId !== '') {
                    tree.insertNewItem(parentId, id, defaultName, 0, 0, 0, 0, 'SELECT');
                    tree.setUserData(id, 'name', defaultName);
                    tree.setUserData(id, 'title', defaultName);
                    editItem(id);
                }
            });

            $save.click(function () {
                var id = tree.getSelectedItemId();
                $.post(options.saveUrl,
                    $.extend({}, {
                        id:id,
                        parent_id:tree.getParentId(id),
                        name:$name.val(),
                        title:$title.val()
                    }, options.hiddenFields),
                    function (item) {
                        console.log(item);
                        if (item['error']) {
                            alert(item['error']);
                        } else {
                            tree.changeItemId(id, item.id);
                            tree.setItemText(item.id, item.title);
                            tree.setUserData(item.id, 'name', item.name);
                            tree.setUserData(item.id, 'title', item.title);
                            editItem(item.id);
                            $save.attr('disabled', 'disabled');
                        }
                    },
                    'json'
                );

            });

            $delete.click(function () {
                confirm(t('Are you sure?'));
                var id = tree.getSelectedItemId();
                $.post(
                    options.deleteUrl,
                    $.extend({}, {id:id}, options.hiddenFields),
                    function (item) {
                        if (item['error']) {

                        } else {
                            tree.deleteItem(id);
                            editItem('root');
                        }
                    },
                    'json');
            });

            function editItem(id) {
                if (id != 'root') {
                    $delete.removeAttr('disabled');
                    $save.removeAttr('disabled');
                    $name.val(tree.getUserData(id, 'name'));
                    $title.val(tree.getUserData(id, 'title'));
                } else {
                    $delete.attr('disabled', 'disabled');
                    $save.attr('disabled', 'disabled');
                    $name.val('');
                    $title.val('');
                }
            }
        });
        return this;
    };

}(jQuery))
;